"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = exports.collectUserFlowsCommand = void 0;
const tslib_1 = require("tslib");
const user_flow_1 = require("./utils/user-flow");
const index_1 = require("../../core/utils/loggin/index");
const interactive_1 = require("../../core/options/interactive");
const dryRun_1 = require("../../core/options/dryRun");
const open_1 = require("./options/open");
const openFileInBrowser = require("open");
const options_1 = require("./options");
const serve_command_1 = require("./utils/serve-command");
const init_1 = require("../init");
exports.collectUserFlowsCommand = {
    command: 'collect',
    description: 'Run a set of user flows and save the result',
    builder: (y) => y.options(options_1.COLLECT_OPTIONS),
    module: {
        handler: (argv) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
            (0, index_1.logVerbose)(`run "collect" as a yargs command with args:`);
            (0, index_1.logVerbose)(argv);
            // get validation and errors for RC & options configurations
            yield (0, init_1.run)(argv);
            const { url, ufPath, outPath, format, budgetPath, budgets, openReport, serveCommand, awaitServeStdout } = argv;
            const r = yield (0, serve_command_1.startServerIfNeeded)(() => {
                return run({ url, ufPath, outPath, format, budgetPath, budgets, openReport, serveCommand, awaitServeStdout });
            }, { serveCommand, awaitServeStdout });
        })
    }
};
function run(cfg) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let { url, ufPath, outPath, format, budgetPath, budgets } = cfg;
        // Load and run user-flows in parallel
        const userFlows = (0, user_flow_1.loadFlow)(ufPath);
        yield sequeltial(userFlows.map(({ exports: provider, path }) => (_) => {
            var _a, _b;
            provider = provider || {};
            if (((_a = provider.flowOptions) === null || _a === void 0 ? void 0 : _a.config) === undefined) {
                provider.flowOptions.config = {};
                if (((_b = provider.flowOptions.config) === null || _b === void 0 ? void 0 : _b.settings) === undefined) {
                    // @ts-ignore
                    provider.flowOptions.config.settings = {};
                }
            }
            if (budgetPath) {
                (0, index_1.logVerbose)(`CLI options --budgetPath or .user-flowrc.json configuration ${budgetPath} is used instead of a potential configuration in the user flow`);
                // @ts-ignore
                provider.flowOptions.config.settings.budgets = budgetPath;
            }
            else if (budgets) {
                (0, index_1.logVerbose)('.user-flowrc.json configuration is used instead of a potential configuration in the user flow');
                // @ts-ignore
                provider.flowOptions.config.settings.budgets = budgets;
            }
            return (0, user_flow_1.collectFlow)({ url, dryRun: (0, dryRun_1.get)() }, Object.assign(Object.assign({}, provider), { path }))
                .then((flow) => (0, user_flow_1.persistFlow)(flow, provider.flowOptions.name, {
                outPath,
                format
            }))
                .then((fileNames) => {
                // open report if requested and not in executed in CI
                if (!(0, dryRun_1.get)() && (0, open_1.get)() && (0, interactive_1.get)()) {
                    const htmlReport = fileNames.find(i => i.includes('.html'));
                    if (htmlReport) {
                        (0, index_1.logVerbose)('open HTML report in browser');
                        openFileInBrowser(htmlReport, { wait: false });
                        return Promise.resolve();
                    }
                    const jsonReport = fileNames.find(i => i.includes('.json'));
                    if (jsonReport) {
                        (0, index_1.logVerbose)('open JSON report in browser');
                        // @TODO if JSON is given open the file in https://googlechrome.github.io/lighthouse/viewer/
                        openFileInBrowser(jsonReport, { wait: false });
                    }
                }
                return Promise.resolve();
            });
        }));
    });
}
exports.run = run;
function sequeltial(set) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let res = undefined;
        for (let i = 0; i < set.length; i++) {
            res = yield set[i](res);
        }
    });
}
//# sourceMappingURL=index.js.map