"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setupFormat = void 0;
const tslib_1 = require("tslib");
const enquirer_1 = require("enquirer");
const interactive_1 = require("../../../core/options/interactive");
const format_constant_1 = require("./format.constant");
const validation_1 = require("../../../core/utils/validation");
const constats_1 = require("../constats");
function setupFormat(config) {
    var _a;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let format = [];
        let cfgFormat = [];
        if ((_a = config === null || config === void 0 ? void 0 : config.persist) === null || _a === void 0 ? void 0 : _a.format) {
            cfgFormat = Array.isArray(config.persist.format) ? config.persist.format : [config.persist.format];
        }
        if (cfgFormat.length === 0) {
            format = constats_1.REPORT_FORMAT_VALUES;
        }
        else {
            format = cfgFormat;
        }
        if ((0, interactive_1.get)()) {
            format = cfgFormat.length === 0 ? yield (0, enquirer_1.prompt)([
                {
                    type: 'multiselect',
                    name: 'f',
                    message: format_constant_1.PROMPT_PERSIST_FORMAT,
                    choices: constats_1.REPORT_FORMAT_OPTIONS,
                    // @NOTICE typing is broken here
                    result(value) {
                        const values = value;
                        return values.map(name => { var _a; return ((_a = constats_1.REPORT_FORMAT_OPTIONS.find(i => i.name === name)) === null || _a === void 0 ? void 0 : _a.value) + ''; });
                    }
                }
            ]).then(({ f }) => f) : cfgFormat;
            if ((format === null || format === void 0 ? void 0 : format.length) === 0) {
                return setupFormat(config);
            }
        }
        // Validate
        const allOf = validation_1.VALIDATORS.allOf(constats_1.REPORT_FORMAT_VALUES);
        const errors = (0, validation_1.applyValidations)(format, [
            validation_1.VALIDATORS.required,
            allOf
        ]);
        if ((0, validation_1.hasError)(errors)) {
            if (errors.required) {
                throw new Error(format_constant_1.ERROR_PERSIST_FORMAT_REQUIRED);
            }
            if (errors.allOf) {
                throw new Error(format_constant_1.ERROR_PERSIST_FORMAT_WRONG);
            }
        }
        return Object.assign(Object.assign({}, config), { persist: Object.assign(Object.assign({}, config === null || config === void 0 ? void 0 : config.persist), { format }) });
    });
}
exports.setupFormat = setupFormat;
/*

export async function ensureFormat(
  config: RcJson
): Promise<RcJson> {
  let suggestion: string[] = [];

  let cfgFormat: string[] = [];
  if (config?.persist?.format) {
    cfgFormat = Array.isArray(config.persist.format) ? config.persist.format : [config.persist.format];
  }

  if (cfgFormat.length === 0) {
    suggestion = REPORT_FORMAT_VALUES;
  } else {
    suggestion = cfgFormat;
  }
  if (interactive()) {
    outPath = await promptParam({
      message: ASK_PERSIST_OUT_PATH,
      initial: outPath || DEFAULT_PERSIST_OUT_PATH,
      skip: !!outPath
    });
  }
  if (interactive()) {

    const { format }: { format: string[] | undefined } = cfgFormat.length === 0 ? await prompt<{ format: string[] }>([
      {
        type: 'multiselect',
        name: 'format',
        message: PROMPT_PERSIST_FORMAT,
        choices: REPORT_FORMAT_OPTIONS,
        // @NOTICE typing is broken here
        result(value: string): string {
          const values = value as any as string[];
          return values.map(name => REPORT_FORMAT_OPTIONS.find(i => i.name === name)?.value + '') as any as string;
        }
      }
    ]) : { format: cfgFormat };

    suggestion = format;
    if (suggestion.length === 0) {
      return ensureFormat(config);
    }
  }

  // Validate
  const allOf = VALIDATORS.allOf(REPORT_FORMAT_VALUES);
  const errors = applyValidations(suggestion, [
    VALIDATORS.required,
    allOf
  ]);
  if (hasError(errors)) {
    if(errors.required) {
      throw new Error(ERROR_PERSIST_FORMAT_REQUIRED);
    }
    if(errors.allOf) {
      throw new Error(ERROR_PERSIST_FORMAT_WRONG);
    }
  }

  return {
    ...config,
    persist: { ...config?.persist, format: suggestion }
  };
}
*/
//# sourceMappingURL=format.setup.js.map