"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadFlow = exports.collectFlow = exports.persistFlow = void 0;
const tslib_1 = require("tslib");
const fs_1 = require("fs");
// @ts-ignore
const api_1 = require("lighthouse/lighthouse-core/fraggle-rock/api");
const puppeteer = require("puppeteer");
const file_1 = require("../../../../core/utils/file");
const path_1 = require("path");
const loggin_1 = require("../../../../core/utils/loggin");
const dryRun_1 = require("../../../../core/options/dryRun");
const cli_modes_1 = require("../../../../cli-modes");
const budgets_1 = require("../../../assert/utils/budgets");
const user_flow_mock_1 = require("./user-flow.mock");
const _persistMethod = new Map();
_persistMethod.set('html', ({ outPath, flow, name }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const report = yield flow.generateReport();
    const fileName = (0, path_1.join)(outPath, `${(0, file_1.toFileName)(name)}.uf.html`);
    (0, file_1.writeFile)(fileName, report);
    return fileName;
}));
_persistMethod.set('json', ({ outPath, flow, name }) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    const report = yield flow.createFlowResult();
    const fileName = (0, path_1.join)(outPath, `${(0, file_1.toFileName)(name)}.uf.json`);
    (0, file_1.writeFile)(fileName, JSON.stringify(report));
    return fileName;
}));
function persistFlow(flow, name, { outPath, format }) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        // @Notice: there might be a bug in user flow and Promise's
        return Promise.all(format.map((f) => _persistMethod.get(f)({ flow, name, outPath })));
    });
}
exports.persistFlow = persistFlow;
function collectFlow(cliOption, userFlowProvider) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let { path, 
        // object containing the LH setting for budgets
        flowOptions: providerFlowOptions, interactions, launchOptions } = userFlowProvider;
        const { config } = providerFlowOptions, rest = tslib_1.__rest(providerFlowOptions, ["config"]);
        const flowOptions = Object.assign(Object.assign({}, rest), { config: parseUserFlowOptionsConfig(providerFlowOptions.config) });
        // object containing the options for pupeteer/chromium
        launchOptions = launchOptions || {
            headless: false,
            // hack for dryRun => should get fixed inside user flow in future
            defaultViewport: { isMobile: true, isLandscape: false, width: 800, height: 600 }
        };
        // @TODO consider CI vs dev mode => headless, open, persist etc
        if ((0, cli_modes_1.detectCliMode)() !== 'DEFAULT') {
            (0, loggin_1.logVerbose)(`Set headless to true as we are running in ${(0, cli_modes_1.detectCliMode)()} mode`);
            launchOptions.headless = true;
        }
        const browser = yield puppeteer.launch(launchOptions);
        const page = yield browser.newPage();
        (0, loggin_1.logVerbose)(`Collect: ${flowOptions.name} from URL ${cliOption.url}`);
        (0, loggin_1.logVerbose)(`File path: ${(0, path_1.normalize)(path)}`);
        let start = Date.now();
        const flow = !(0, dryRun_1.get)() ? yield (0, api_1.startFlow)(page, flowOptions) : new user_flow_mock_1.UserFlowMock(page, flowOptions);
        // run custom interactions
        yield interactions({ flow, page, browser, collectOptions: cliOption });
        (0, loggin_1.logVerbose)(`Duration: ${flowOptions.name}: ${(Date.now() - start) / 1000}`);
        yield browser.close();
        return flow;
    });
}
exports.collectFlow = collectFlow;
function loadFlow(path) {
    let ufDirectory = [];
    try {
        ufDirectory = (0, fs_1.readdirSync)(path);
    }
    catch (e) {
        throw new Error(`ufPath: ${path} is no directory`);
    }
    const flows = (0, fs_1.readdirSync)(path).map((p) => (0, file_1.resolveAnyFile)((0, path_1.join)(path, p)));
    return flows;
}
exports.loadFlow = loadFlow;
function parseUserFlowOptionsConfig(flowOptionsConfig) {
    var _a, _b;
    flowOptionsConfig = flowOptionsConfig || {};
    // @ts-ignore
    (flowOptionsConfig === null || flowOptionsConfig === void 0 ? void 0 : flowOptionsConfig.extends) || (flowOptionsConfig.extends = 'lighthouse:default');
    // if budgets are given
    if ((_a = flowOptionsConfig === null || flowOptionsConfig === void 0 ? void 0 : flowOptionsConfig.settings) === null || _a === void 0 ? void 0 : _a.budgets) {
        (0, loggin_1.logVerbose)('format given budgets');
        let budgets = (_b = flowOptionsConfig === null || flowOptionsConfig === void 0 ? void 0 : flowOptionsConfig.settings) === null || _b === void 0 ? void 0 : _b.budgets;
        budgets && (budgets = Array.isArray(budgets) ? budgets : (0, budgets_1.readBudgets)(budgets));
        flowOptionsConfig.settings.budgets = budgets;
    }
    return flowOptionsConfig;
}
//# sourceMappingURL=index.js.map