"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toFileName = exports.resolveAnyFile = exports.writeFile = exports.readFile = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
const loggin_1 = require("./loggin");
const prettier_1 = require("./prettier");
/**
 * Ensures the file exists before reading it
 */
function readFile(path) {
    try {
        if ((0, fs_1.existsSync)(path)) {
            return (0, fs_1.readFileSync)(path, 'utf-8');
        }
        else {
            (0, loggin_1.logVerbose)(path + ' does not exist.');
        }
    }
    catch (e) {
        (0, loggin_1.logVerbose)(path + ' caused error');
    }
    return '';
}
exports.readFile = readFile;
/**
 * Ensures the folder exists before writing it
 */
function writeFile(filePath, data) {
    const dir = (0, path_1.dirname)(filePath);
    if (!(0, fs_1.existsSync)(dir)) {
        (0, loggin_1.logVerbose)(`Created dir ${dir} to save ${filePath}`);
        (0, fs_1.mkdirSync)(dir);
    }
    // @TODO implement a check that saves the file only if the content is different => git noise
    const ext = (0, path_1.extname)(filePath);
    const formattedData = (0, prettier_1.formatCode)(data, (0, prettier_1.getParserFromExtname)(ext));
    return (0, fs_1.writeFileSync)(filePath, formattedData);
}
exports.writeFile = writeFile;
function resolveAnyFile(path) {
    // start path from cwd
    path = (0, path_1.join)(process.cwd(), path);
    let file;
    // 🔥 Live compilation of TypeScript files
    if (path.endsWith('.ts')) {
        // Register TS compiler lazily
        // tsNode needs the compilerOptions.module resolution to be 'commonjs',
        // so that imports in the `*.uf.ts` files work.
        require('ts-node').register({
            'compilerOptions': {
                'module': 'commonjs'
            }
        });
    }
    file = require(path);
    // If the user provides a configuration in TS file
    // then there are 2 cases for exporing an object. The first one is:
    // `module.exports = { ... }`. And the second one is:
    // `export default { ... }`. The ESM format is compiled into:
    // `{ default: { ... } }`
    const exports = file.default || file;
    return { exports, path };
}
exports.resolveAnyFile = resolveAnyFile;
/**
 * Upper or camelCase to lowercase hyphenated
 */
function toFileName(s) {
    return s
        .replace(/([a-z\d])([A-Z])/g, '$1_$2')
        .toLowerCase()
        .replace(/[ _]/g, '-')
        .replace(/[/\\]/g, '-');
}
exports.toFileName = toFileName;
//# sourceMappingURL=file.js.map